//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Tile](index.md)/[distance](distance.md)

# distance

[common]\
fun [distance](distance.md)(that: [Tile](index.md)): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)

计算这张牌与另一张牌的数字之差

#### Parameters

common

| | |
|---|---|
| that | 另一张牌 |
